@@ -125,6 +125,11 @@ int Sketch::initFromFiles(const vector<string> & files, const Parameters & param
             	continue;
             }
 			
+            if ( sketchTest.getHashSeed() != parameters.seed )
+            {
+				cerr << "\nWARNING: The sketch " << files[i] << " has a seed size (" << sketchTest.getHashSeed() << ") that does not match the current seed (" << parameters.seed << "). This file will be skipped." << endl << endl;
+				continue;
+            }
 			if ( sketchTest.getKmerSize() != parameters.kmerSize )
 			{
 				cerr << "\nWARNING: The sketch " << files[i] << " has a kmer size (" << sketchTest.getKmerSize() << ") that does not match the current kmer size (" << parameters.kmerSize << "). This file will be skipped." << endl << endl;
@@ -232,7 +237,7 @@ int Sketch::initFromFiles(const vector<string> & files, const Parameters & param
     return 0;
 }
 
-void Sketch::initParametersFromCapnp(const char * file)
+uint64_t Sketch::initParametersFromCapnp(const char * file)
 {
     int fd = open(file, O_RDONLY);
     
@@ -242,13 +247,23 @@ void Sketch::initParametersFromCapnp(const char * file)
         exit(1);
     }
     
+    struct stat fileInfo;
+    
+    if ( stat(file, &fileInfo) == -1 )
+    {
+        cerr << "ERROR: could not get file stats for \"" << file << "\"." << endl;
+        exit(1);
+    }
+    
+    void * data = mmap(NULL, fileInfo.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
+    
     capnp::ReaderOptions readerOptions;
     
     readerOptions.traversalLimitInWords = 1000000000000;
     readerOptions.nestingLimit = 1000000;
     
-    capnp::StreamFdMessageReader * message = new capnp::StreamFdMessageReader(fd, readerOptions);
-    //capnp::FlatArrayMessageReader * message = new capnp::FlatArrayMessageReader(kj::ArrayPtr<const capnp::word>(reinterpret_cast<const capnp::word *>(data), fileInfo.st_size / sizeof(capnp::word)), readerOptions);
+    //capnp::StreamFdMessageReader * message = new capnp::StreamFdMessageReader(fd, readerOptions);
+    capnp::FlatArrayMessageReader * message = new capnp::FlatArrayMessageReader(kj::ArrayPtr<const capnp::word>(reinterpret_cast<const capnp::word *>(data), fileInfo.st_size / sizeof(capnp::word)), readerOptions);
     capnp::MinHash::Reader reader = message->getRoot<capnp::MinHash>();
     
     parameters.kmerSize = reader.getKmerSize();
@@ -258,6 +273,12 @@ void Sketch::initParametersFromCapnp(const char * file)
     parameters.concatenated = reader.getConcatenated();
     parameters.noncanonical = reader.getNoncanonical();
    	parameters.preserveCase = reader.getPreserveCase();
+
+    capnp::MinHash::ReferenceList::Reader referenceListReader = reader.getReferenceList().getReferences().size() ? reader.getReferenceList() : reader.getReferenceListOld();
+    capnp::List<capnp::MinHash::ReferenceList::Reference>::Reader referencesReader = referenceListReader.getReferences();
+    uint64_t referenceCount = referencesReader.size();
+    
+   	parameters.seed = reader.getHashSeed();
     
     if ( reader.hasAlphabet() )
     {
@@ -274,6 +295,8 @@ void Sketch::initParametersFromCapnp(const char * file)
 		delete message;
 	}
 	catch (exception e) {}
+	
+	return referenceCount;
 }
 
 bool Sketch::sketchFileBySequence(FILE * file, ThreadPool<Sketch::SketchInput, Sketch::SketchOutput> * threadPool)
@@ -347,7 +370,7 @@ int Sketch::writeToCapnp(const char * file) const
     capnp::MallocMessageBuilder message;
     capnp::MinHash::Builder builder = message.initRoot<capnp::MinHash>();
     
-    capnp::MinHash::ReferenceList::Builder referenceListBuilder = builder.initReferenceList();
+    capnp::MinHash::ReferenceList::Builder referenceListBuilder = (parameters.seed == 42 ? builder.initReferenceListOld() : builder.initReferenceList());
     
     capnp::List<capnp::MinHash::ReferenceList::Reference>::Builder referencesBuilder = referenceListBuilder.initReferences(references.size());
     
@@ -422,6 +445,7 @@ int Sketch::writeToCapnp(const char * file) const
     }
     
     builder.setKmerSize(parameters.kmerSize);
+    builder.setHashSeed(parameters.seed);
     builder.setError(parameters.error);
     builder.setMinHashesPerWindow(parameters.minHashesPerWindow);
     builder.setWindowSize(parameters.windowSize);
@@ -549,7 +573,7 @@ void addMinHashes(MinHashHeap & minHashHeap, char * seq, uint64_t length, const
         const char * kmer = useRevComp ? seqRev + length - i - kmerSize : seq + i;
         bool filter = false;
         
-        hash_u hash = getHash(useRevComp ? seqRev + length - i - kmerSize : seq + i, kmerSize, parameters.use64);
+        hash_u hash = getHash(useRevComp ? seqRev + length - i - kmerSize : seq + i, kmerSize, parameters.seed, parameters.use64);
         
         if ( debug ) cout << endl;
         
@@ -660,7 +684,7 @@ void getMinHashPositions(vector<Sketch::PositionHash> & positionHashes, char * s
         
         if ( i >= nextValidKmer )
         {
-            Sketch::hash_t hash = getHash(seq + i, kmerSize, parameters.use64).hash64; // TODO: dynamic
+            Sketch::hash_t hash = getHash(seq + i, kmerSize, parameters.seed, parameters.use64).hash64; // TODO: dynamic
             
             if ( verbosity > 1 )
             {
@@ -909,7 +933,7 @@ Sketch::SketchOutput * loadCapnp(Sketch::SketchInput * input)
     capnp::FlatArrayMessageReader * message = new capnp::FlatArrayMessageReader(kj::ArrayPtr<const capnp::word>(reinterpret_cast<const capnp::word *>(data), fileInfo.st_size / sizeof(capnp::word)), readerOptions);
     capnp::MinHash::Reader reader = message->getRoot<capnp::MinHash>();
     
-    capnp::MinHash::ReferenceList::Reader referenceListReader = reader.getReferenceList();
+    capnp::MinHash::ReferenceList::Reader referenceListReader = reader.getReferenceList().getReferences().size() ? reader.getReferenceList() : reader.getReferenceListOld();
     
     capnp::List<capnp::MinHash::ReferenceList::Reference>::Reader referencesReader = referenceListReader.getReferences();
     
@@ -1105,18 +1129,17 @@ void setMinHashesForReference(Sketch::Reference & reference, const MinHashHeap &
 
 Sketch::SketchOutput * sketchFile(Sketch::SketchInput * input)
 {
-	FILE * inStream = 0;
+	gzFile fp;
 	
 	if ( input->fileName == "-" )
 	{
-		inStream = stdin;
+		fp = gzdopen(fileno(stdin), "r");
 	}
 	else
 	{
-		inStream = fopen(input->fileName.c_str(), "r");
+		fp = gzopen(input->fileName.c_str(), "r");
 	}
 	
-	gzFile fp = gzdopen(fileno(inStream), "r");
 	kseq_t *seq = kseq_init(fp);
 	
 	const Sketch::Parameters & parameters = input->parameters;
@@ -1224,7 +1247,6 @@ Sketch::SketchOutput * sketchFile(Sketch::SketchInput * input)
 	
 	kseq_destroy(seq);
 	gzclose(fp);
-	fclose(inStream);
 	
 	return output;
 }
