@@ -36,11 +36,12 @@ public:
     {
         Parameters()
             :
-            parallelism(0),
+            parallelism(1),
             kmerSize(0),
             alphabetSize(0),
             preserveCase(false),
             use64(false),
+            seed(0),
             error(0),
             warning(0),
             minHashesPerWindow(0),
@@ -50,7 +51,7 @@ public:
             noncanonical(false),
             reads(false),
             memoryBound(0),
-            minCov(0),
+            minCov(1),
             targetCov(0),
             genomeSize(0)
         {
@@ -64,6 +65,7 @@ public:
             alphabetSize(other.alphabetSize),
             preserveCase(other.preserveCase),
             use64(other.use64),
+            seed(other.seed),
             error(other.error),
             warning(other.warning),
             minHashesPerWindow(other.minHashesPerWindow),
@@ -86,6 +88,7 @@ public:
         uint32_t alphabetSize;
         bool preserveCase;
         bool use64;
+        uint32_t seed;
         double error;
         double warning;
         uint64_t minHashesPerWindow;
@@ -179,6 +182,7 @@ public:
     bool getConcatenated() const {return parameters.concatenated;}
     float getError() const {return parameters.error;}
     int getHashCount() const {return lociByHash.size();}
+    uint32_t getHashSeed() const {return parameters.seed;}
     const std::vector<Locus> & getLociByHash(hash_t hash) const;
     float getMinHashesPerWindow() const {return parameters.minHashesPerWindow;}
 	int getMinKmerSize(uint64_t reference) const;
@@ -196,7 +200,7 @@ public:
     bool hasHashCounts() const {return references.size() > 0 && references.at(0).counts.size() > 0;}
     bool hasLociByHash(hash_t hash) const {return lociByHash.count(hash);}
     int initFromFiles(const std::vector<std::string> & files, const Parameters & parametersNew, int verbosity = 0, bool enforceParameters = false, bool contain = false);
-    void initParametersFromCapnp(const char * file);
+    uint64_t initParametersFromCapnp(const char * file);
 	bool sketchFileBySequence(FILE * file, ThreadPool<Sketch::SketchInput, Sketch::SketchOutput> * threadPool);
 	void useThreadOutput(SketchOutput * output);
     void warnKmerSize(uint64_t lengthMax, const std::string & lengthMaxName, double randomChance, int kMin, int warningCount) const;
