@@ -7,7 +7,10 @@
 #include "sketchParameterSetup.h"
 #include <iostream>
 
-using namespace::std;
+using std::cerr;
+using std::endl;
+
+namespace mash {
 
 int sketchParameterSetup(Sketch::Parameters & parameters, const Command & command)
 {
@@ -15,6 +18,7 @@ int sketchParameterSetup(Sketch::Parameters & parameters, const Command & comman
     parameters.minHashesPerWindow = command.getOption("sketchSize").getArgumentAsNumber();
     parameters.concatenated = ! command.getOption("individual").active;
     parameters.noncanonical = command.getOption("noncanonical").active;
+    parameters.seed = command.getOption("seed").getArgumentAsNumber();
     parameters.reads = command.getOption("reads").active;
     parameters.minCov = command.getOption("minCov").getArgumentAsNumber();
     parameters.targetCov = command.getOption("targetCov").getArgumentAsNumber();
@@ -110,3 +114,4 @@ void warnKmerSize(const Sketch::Parameters & parameters, const Command & command
 		<< " is required. See: -" << command.getOption("kmer").identifier << ", -" << command.getOption("warning").identifier << "." << endl << endl;
 }
 
+} // namespace mash
\ No newline at end of file
